/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.adsense.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for AdUnit.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the AdSense Management API. For a detailed explanation
 * see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class AdUnit extends GenericJson {

  /**
   * Identity code of this ad unit, not necessarily unique across ad clients.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String code;

  /**
   * Settings specific to content ads (AFC) and highend mobile content ads (AFMC).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private ContentAdsSettings contentAdsSettings;

  /**
   * Custom style information specific to this ad unit.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private AdStyle customStyle;

  /**
   * Settings specific to feed ads (AFF).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private FeedAdsSettings feedAdsSettings;

  /**
   * Unique identifier of this ad unit. This should be considered an opaque identifier; it is not
   * safe to rely on it being in any particular format.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * Kind of resource this is, in this case adsense#adUnit.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Settings specific to WAP mobile content ads (AFMC).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private MobileContentAdsSettings mobileContentAdsSettings;

  /**
   * Name of this ad unit.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String name;

  /**
   * ID of the saved ad style which holds this ad unit's style information.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String savedStyleId;

  /**
   * Status of this ad unit. Possible values are: NEW: Indicates that the ad unit was created within
   * the last seven days and does not yet have any activity associated with it.
   *
   * ACTIVE: Indicates that there has been activity on this ad unit in the last seven days.
   *
   * INACTIVE: Indicates that there has been no activity on this ad unit in the last seven days.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String status;

  /**
   * Identity code of this ad unit, not necessarily unique across ad clients.
   * The value returned may be {@code null}.
   */
  public String getCode() {
    return code;
  }

  /**
   * Identity code of this ad unit, not necessarily unique across ad clients.
   * The value set may be {@code null}.
   */
  public AdUnit setCode(String code) {
    this.code = code;
    return this;
  }

  /**
   * Settings specific to content ads (AFC) and highend mobile content ads (AFMC).
   * The value returned may be {@code null}.
   */
  public ContentAdsSettings getContentAdsSettings() {
    return contentAdsSettings;
  }

  /**
   * Settings specific to content ads (AFC) and highend mobile content ads (AFMC).
   * The value set may be {@code null}.
   */
  public AdUnit setContentAdsSettings(ContentAdsSettings contentAdsSettings) {
    this.contentAdsSettings = contentAdsSettings;
    return this;
  }

  /**
   * Custom style information specific to this ad unit.
   * The value returned may be {@code null}.
   */
  public AdStyle getCustomStyle() {
    return customStyle;
  }

  /**
   * Custom style information specific to this ad unit.
   * The value set may be {@code null}.
   */
  public AdUnit setCustomStyle(AdStyle customStyle) {
    this.customStyle = customStyle;
    return this;
  }

  /**
   * Settings specific to feed ads (AFF).
   * The value returned may be {@code null}.
   */
  public FeedAdsSettings getFeedAdsSettings() {
    return feedAdsSettings;
  }

  /**
   * Settings specific to feed ads (AFF).
   * The value set may be {@code null}.
   */
  public AdUnit setFeedAdsSettings(FeedAdsSettings feedAdsSettings) {
    this.feedAdsSettings = feedAdsSettings;
    return this;
  }

  /**
   * Unique identifier of this ad unit. This should be considered an opaque identifier; it is not
   * safe to rely on it being in any particular format.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * Unique identifier of this ad unit. This should be considered an opaque identifier; it is not
   * safe to rely on it being in any particular format.
   * The value set may be {@code null}.
   */
  public AdUnit setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * Kind of resource this is, in this case adsense#adUnit.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * Kind of resource this is, in this case adsense#adUnit.
   * The value set may be {@code null}.
   */
  public AdUnit setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Settings specific to WAP mobile content ads (AFMC).
   * The value returned may be {@code null}.
   */
  public MobileContentAdsSettings getMobileContentAdsSettings() {
    return mobileContentAdsSettings;
  }

  /**
   * Settings specific to WAP mobile content ads (AFMC).
   * The value set may be {@code null}.
   */
  public AdUnit setMobileContentAdsSettings(MobileContentAdsSettings mobileContentAdsSettings) {
    this.mobileContentAdsSettings = mobileContentAdsSettings;
    return this;
  }

  /**
   * Name of this ad unit.
   * The value returned may be {@code null}.
   */
  public String getName() {
    return name;
  }

  /**
   * Name of this ad unit.
   * The value set may be {@code null}.
   */
  public AdUnit setName(String name) {
    this.name = name;
    return this;
  }

  /**
   * ID of the saved ad style which holds this ad unit's style information.
   * The value returned may be {@code null}.
   */
  public String getSavedStyleId() {
    return savedStyleId;
  }

  /**
   * ID of the saved ad style which holds this ad unit's style information.
   * The value set may be {@code null}.
   */
  public AdUnit setSavedStyleId(String savedStyleId) {
    this.savedStyleId = savedStyleId;
    return this;
  }

  /**
   * Status of this ad unit. Possible values are: NEW: Indicates that the ad unit was created within
   * the last seven days and does not yet have any activity associated with it.
   *
   * ACTIVE: Indicates that there has been activity on this ad unit in the last seven days.
   *
   * INACTIVE: Indicates that there has been no activity on this ad unit in the last seven days.
   * The value returned may be {@code null}.
   */
  public String getStatus() {
    return status;
  }

  /**
   * Status of this ad unit. Possible values are: NEW: Indicates that the ad unit was created within
   * the last seven days and does not yet have any activity associated with it.
   *
   * ACTIVE: Indicates that there has been activity on this ad unit in the last seven days.
   *
   * INACTIVE: Indicates that there has been no activity on this ad unit in the last seven days.
   * The value set may be {@code null}.
   */
  public AdUnit setStatus(String status) {
    this.status = status;
    return this;
  }

  /**
   * Settings specific to content ads (AFC) and highend mobile content ads (AFMC).
   */
  public static final class ContentAdsSettings extends GenericJson {

    /**
     * The backup option to be used in instances where no ad is available.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private BackupOption backupOption;

    /**
     * Size of this ad unit.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String size;

    /**
     * Type of this ad unit.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String type;

    /**
     * The backup option to be used in instances where no ad is available.
     * The value returned may be {@code null}.
     */
    public BackupOption getBackupOption() {
      return backupOption;
    }

    /**
     * The backup option to be used in instances where no ad is available.
     * The value set may be {@code null}.
     */
    public ContentAdsSettings setBackupOption(BackupOption backupOption) {
      this.backupOption = backupOption;
      return this;
    }

    /**
     * Size of this ad unit.
     * The value returned may be {@code null}.
     */
    public String getSize() {
      return size;
    }

    /**
     * Size of this ad unit.
     * The value set may be {@code null}.
     */
    public ContentAdsSettings setSize(String size) {
      this.size = size;
      return this;
    }

    /**
     * Type of this ad unit.
     * The value returned may be {@code null}.
     */
    public String getType() {
      return type;
    }

    /**
     * Type of this ad unit.
     * The value set may be {@code null}.
     */
    public ContentAdsSettings setType(String type) {
      this.type = type;
      return this;
    }

    /**
     * The backup option to be used in instances where no ad is available.
     */
    public static final class BackupOption extends GenericJson {

      /**
       * Color to use when type is set to COLOR.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String color;

      /**
       * Type of the backup option. Possible values are BLANK, COLOR and URL.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String type;

      /**
       * URL to use when type is set to URL.
       * The value may be {@code null}.
       */
      @com.google.api.client.util.Key
      private String url;

      /**
       * Color to use when type is set to COLOR.
       * The value returned may be {@code null}.
       */
      public String getColor() {
        return color;
      }

      /**
       * Color to use when type is set to COLOR.
       * The value set may be {@code null}.
       */
      public BackupOption setColor(String color) {
        this.color = color;
        return this;
      }

      /**
       * Type of the backup option. Possible values are BLANK, COLOR and URL.
       * The value returned may be {@code null}.
       */
      public String getType() {
        return type;
      }

      /**
       * Type of the backup option. Possible values are BLANK, COLOR and URL.
       * The value set may be {@code null}.
       */
      public BackupOption setType(String type) {
        this.type = type;
        return this;
      }

      /**
       * URL to use when type is set to URL.
       * The value returned may be {@code null}.
       */
      public String getUrl() {
        return url;
      }

      /**
       * URL to use when type is set to URL.
       * The value set may be {@code null}.
       */
      public BackupOption setUrl(String url) {
        this.url = url;
        return this;
      }

    }
  }

  /**
   * Settings specific to feed ads (AFF).
   */
  public static final class FeedAdsSettings extends GenericJson {

    /**
     * The position of the ads relative to the feed entries.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String adPosition;

    /**
     * The frequency at which ads should appear in the feed (i.e. every N entries).
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer frequency;

    /**
     * The minimum length an entry should be in order to have attached ads.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Integer minimumWordCount;

    /**
     * The type of ads which should appear.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String type;

    /**
     * The position of the ads relative to the feed entries.
     * The value returned may be {@code null}.
     */
    public String getAdPosition() {
      return adPosition;
    }

    /**
     * The position of the ads relative to the feed entries.
     * The value set may be {@code null}.
     */
    public FeedAdsSettings setAdPosition(String adPosition) {
      this.adPosition = adPosition;
      return this;
    }

    /**
     * The frequency at which ads should appear in the feed (i.e. every N entries).
     * The value returned may be {@code null}.
     */
    public Integer getFrequency() {
      return frequency;
    }

    /**
     * The frequency at which ads should appear in the feed (i.e. every N entries).
     * The value set may be {@code null}.
     */
    public FeedAdsSettings setFrequency(Integer frequency) {
      this.frequency = frequency;
      return this;
    }

    /**
     * The minimum length an entry should be in order to have attached ads.
     * The value returned may be {@code null}.
     */
    public Integer getMinimumWordCount() {
      return minimumWordCount;
    }

    /**
     * The minimum length an entry should be in order to have attached ads.
     * The value set may be {@code null}.
     */
    public FeedAdsSettings setMinimumWordCount(Integer minimumWordCount) {
      this.minimumWordCount = minimumWordCount;
      return this;
    }

    /**
     * The type of ads which should appear.
     * The value returned may be {@code null}.
     */
    public String getType() {
      return type;
    }

    /**
     * The type of ads which should appear.
     * The value set may be {@code null}.
     */
    public FeedAdsSettings setType(String type) {
      this.type = type;
      return this;
    }

  }

  /**
   * Settings specific to WAP mobile content ads (AFMC).
   */
  public static final class MobileContentAdsSettings extends GenericJson {

    /**
     * The markup language to use for this ad unit.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String markupLanguage;

    /**
     * The scripting language to use for this ad unit.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String scriptingLanguage;

    /**
     * Size of this ad unit.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String size;

    /**
     * Type of this ad unit.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String type;

    /**
     * The markup language to use for this ad unit.
     * The value returned may be {@code null}.
     */
    public String getMarkupLanguage() {
      return markupLanguage;
    }

    /**
     * The markup language to use for this ad unit.
     * The value set may be {@code null}.
     */
    public MobileContentAdsSettings setMarkupLanguage(String markupLanguage) {
      this.markupLanguage = markupLanguage;
      return this;
    }

    /**
     * The scripting language to use for this ad unit.
     * The value returned may be {@code null}.
     */
    public String getScriptingLanguage() {
      return scriptingLanguage;
    }

    /**
     * The scripting language to use for this ad unit.
     * The value set may be {@code null}.
     */
    public MobileContentAdsSettings setScriptingLanguage(String scriptingLanguage) {
      this.scriptingLanguage = scriptingLanguage;
      return this;
    }

    /**
     * Size of this ad unit.
     * The value returned may be {@code null}.
     */
    public String getSize() {
      return size;
    }

    /**
     * Size of this ad unit.
     * The value set may be {@code null}.
     */
    public MobileContentAdsSettings setSize(String size) {
      this.size = size;
      return this;
    }

    /**
     * Type of this ad unit.
     * The value returned may be {@code null}.
     */
    public String getType() {
      return type;
    }

    /**
     * Type of this ad unit.
     * The value set may be {@code null}.
     */
    public MobileContentAdsSettings setType(String type) {
      this.type = type;
      return this;
    }

  }

}
